package sun.text.normalizer;

import java.io.IOException;
import java.io.InputStream;
import java.io.DataInputStream;

final class NormalizerDataReader implements ICUBinary.Authenticate
{
    private DataInputStream dataInputStream;
    private byte[] unicodeVersion;
    private static final byte[] DATA_FORMAT_ID;
    private static final byte[] DATA_FORMAT_VERSION;
    
    protected NormalizerDataReader(InputStream in) throws IOException {
        this.unicodeVersion = ICUBinary.readHeader(in, NormalizerDataReader.DATA_FORMAT_ID, this);
        this.dataInputStream = new DataInputStream(in);
    }
    
    protected int[] readIndexes(int n) throws IOException {
        int[] array = new int[n];
        for (int i = 0; i < n; ++i) {
            array[i] = this.dataInputStream.readInt();
        }
        return array;
    }
    
    protected void read(byte[] b, byte[] b2, byte[] b3, char[] array, char[] array2) throws IOException {
        this.dataInputStream.readFully(b);
        for (int i = 0; i < array.length; ++i) {
            array[i] = this.dataInputStream.readChar();
        }
        for (int j = 0; j < array2.length; ++j) {
            array2[j] = this.dataInputStream.readChar();
        }
        this.dataInputStream.readFully(b2);
        this.dataInputStream.readFully(b3);
    }
    
    public byte[] getDataFormatVersion() {
        return NormalizerDataReader.DATA_FORMAT_VERSION;
    }
    
    @Override
    public boolean isDataVersionAcceptable(byte[] array) {
        return array[0] == NormalizerDataReader.DATA_FORMAT_VERSION[0] && array[2] == NormalizerDataReader.DATA_FORMAT_VERSION[2] && array[3] == NormalizerDataReader.DATA_FORMAT_VERSION[3];
    }
    
    public byte[] getUnicodeVersion() {
        return this.unicodeVersion;
    }
    
    static {
        DATA_FORMAT_ID = new byte[] { 78, 111, 114, 109 };
        DATA_FORMAT_VERSION = new byte[] { 2, 2, 5, 2 };
    }
}
